pub struct Template<'a> { /* private fields */ }Expand description
A parsed template that can be rendered multiple times efficiently
Implementations
Sourceimpl<'a> Template<'a>
impl<'a> Template<'a>
Sourcepub fn render(
&self,
registry: &ModuleRegistry,
context: &ModuleContext,
) -> Result<String>
pub fn render( &self, registry: &ModuleRegistry, context: &ModuleContext, ) -> Result<String>
Render the template with the given registry and context
Sourcepub fn tokens(&self) -> impl Iterator<Item = &Token<'a>>
pub fn tokens(&self) -> impl Iterator<Item = &Token<'a>>
Get an iterator over the tokens in this template
Sourcepub fn token_count(&self) -> usize
pub fn token_count(&self) -> usize
Get the number of tokens in this template